<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Notification;
use App\Models\SubscriptionTransfer;
use App\Models\UserToken;
use App\User;
use Carbon\Carbon;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;

class SubscriptionTransfersController extends Controller
{
    public function index()
    {
        $rows = SubscriptionTransfer::whereTransferType('banking')->get();
        return view('admin.subscription_transfers.index', compact('rows'));
    }

    public function destroy($id)
    {
        SubscriptionTransfer::destroy($id);
        toast('تم الحذف بنجاح', 'success');
        return redirect()->back();
    }

    public function show($id)
    {
        $row = SubscriptionTransfer::find($id);
        return view('admin.subscription_transfers.show', compact('row'));
    }

    public function update($id, Request $request)
    {
        $request->validate([
            'status' => 'required'
        ]);
        $transfer = SubscriptionTransfer::find($id);
        if ($request['status'] == 'approved') {
            $transfer['status'] = $request['status'];
            $transfer->update();
            $user = $transfer->user;
            $user['subscription_status'] = 'true';
            $user['subscription_date'] = Carbon::now();
            $user['subscription_id'] = $transfer->package_id;
            $user->update();


            $tokens = UserToken::whereStatus('connected')->whereUserId($user->id)->get();

            $notification = new Notification();
            $notification['user_id'] = $user->id;
            $notification['body->ar'] = 'تمت الموافقه علي طلبكم بخصوص الإشتراك';
            $notification['body->en'] = "Your request regarding participation has been approved";
            $notification['type'] = 'admin';
            $notification->save();


            foreach ($tokens as $token) {
                if ($token->lang = 'ar') {
                    $title = $notification->body['ar'];
                    $body = $notification->body['ar'];
                } else {
                    $title = $notification->body['en'];
                    $body = $notification->body['en'];
                }
                $push = new PushNotification('fcm');

                if ($token->device_type == 'ios') {

                    $msg = [
                        'data' => [
                            'title_ar' => $notification->body['ar'],
                            'title' => $title,
                            'body' => $body,
                            'title_en' => $notification->body['en'],
                            'body_ar' => $notification->body['ar'],
                            'body_en' => $notification->body['en'],
                            'type' => 'admin',
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $notification->body['ar'],
                            'title_en' => $notification->body['en'],
                            'body_ar' => $notification->body['ar'],
                            'body_en' => $notification->body['en'],
                            'type' => 'admin',
                            'title' => $title,
                            'body' => $body,

                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification->body['ar'],
                            'title_en' => $notification->body['en'],
                            'body_ar' => $notification->body['ar'],
                            'body_en' => $notification->body['en'],
                            'type' => 'admin',
                            'title' => $title,
                            'body' => $body,
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }

            }


        } elseif ($request['status'] == 'failed') {
            $transfer['status'] = $request['status'];
            $transfer->update();


            $tokens = UserToken::whereStatus('connected')->whereUserId($transfer->user_id)->get();

            $notification = new Notification();
            $notification['user_id'] = $transfer->user_id;
            $notification['body->ar'] = 'تم الرفض علي طلبكم بخصوص الإشتراك';
            $notification['body->en'] = "Your request regarding participation was rejected";
            $notification['type'] = 'admin';
            $notification->save();


            foreach ($tokens as $token) {
                if ($token->lang = 'ar') {
                    $title = $notification->body['ar'];
                    $body = $notification->body['ar'];
                } else {
                    $title = $notification->body['en'];
                    $body = $notification->body['en'];
                }
                $push = new PushNotification('fcm');

                if ($token->device_type == 'ios') {

                    $msg = [
                        'data' => [
                            'title_ar' => $notification->body['ar'],
                            'title' => $title,
                            'body' => $body,
                            'title_en' => $notification->body['en'],
                            'body_ar' => $notification->body['ar'],
                            'body_en' => $notification->body['en'],
                            'type' => 'admin',
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $notification->body['ar'],
                            'title_en' => $notification->body['en'],
                            'body_ar' => $notification->body['ar'],
                            'body_en' => $notification->body['en'],
                            'type' => 'admin',
                            'title' => $title,
                            'body' => $body,

                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification->body['ar'],
                            'title_en' => $notification->body['en'],
                            'body_ar' => $notification->body['ar'],
                            'body_en' => $notification->body['en'],
                            'type' => 'admin',
                            'title' => $title,
                            'body' => $body,
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }

            }
        } else {

            $transfer['status'] = $request['status'];
            $transfer->update();


        }
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('subscription_transfers.index');
    }
}
