<?php

namespace App;

use App\Models\Category;
use App\Models\Certifications;
use App\Models\City;
use App\Models\Notification;
use App\Models\Package;
use App\Models\TransfersRequest;
use App\Models\UserToken;
use App\Models\WorkerImage;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Tymon\JWTAuth\Contracts\JWTSubject;

class User extends Authenticatable implements JWTSubject
{
    use Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = array('username', 'mobile', 'email', 'city_id', 'type', 'password', 'image', 'code', 'wallet', 'experience', 'category_type', 'lat', 'lng', 'status', 'commercial_number', 'delivery',
        'subscription_date', 'subscription_status', 'subscription_id');

    protected $appends = ['job'];

    public function getJobAttribute()
    {
        $lang = request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $job_name = [];
        $worker_job_name = '';
        foreach ($this->worker_categories as $worker_category) {
            $job_name[] = $worker_category->name[$lang];
        }
        $worker_job_name = implode(", ", $job_name);
        return $worker_job_name;
//        return $str;

    }

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];


    public function getJWTIdentifier()
    {
        return $this->getKey();
    }

    public function getJWTCustomClaims()
    {
        return [];
    }


    // relations
    public function city()
    {
        return $this->belongsTo(City::class, 'city_id');
    }

    public function tokens()
    {
        return $this->hasMany(UserToken::class, 'user_id');
    }

    public function worker_categories()
    {
        return $this->belongsToMany(Category::class, 'workers_categories', 'worker_id', 'category_id');
    }

    public function notifications()
    {
        return $this->hasMany(Notification::class, 'user_id');
    }

    public function transfers_request()
    {
        return $this->hasMany(TransfersRequest::class, 'user_id');
    }


    public function worker_images()
    {
        return $this->hasMany(WorkerImage::class, 'user_id');
    }

    public function package()
    {
        return $this->belongsTo(Package::class, 'subscription_id');
    }

    public function certifications()
    {
        return $this->hasMany(Certifications::class, 'worker_id');

    }
}
